@@ -65,10 +65,11 @@ class Publisher:
                 try:
                     message = await self._publish_stream.get()
                     assert type(message) is dict, "Only dictionary type is processed by this publisher."
+                    assert self._channel is not None, f"Please supply valid publication channel. {self._channel} is not valid. "
                     await self._redis.publish_json(self._channel, message)
                     await asyncio.sleep(0.1)
                 except AssertionError as e:
-                    self.logger().error(f"{e}. {type(message)} is not compatible to 'dict'. Message is ignored. ")
+                    self.logger().error(f"{e}. {type(message)}")
         except asyncio.CancelledError:
             raise
         except Exception:
